@@ -41,8 +41,10 @@ enum
 	COL_PID,
 	COL_SECURITYCONTEXT,
 	COL_ARGS,
+	COL_MEM,
 	COL_PIXBUF,
 	COL_POINTER,
+	COL_TOOLTIP,
 	NUM_COLUMNS
 };
 
